What’s new in release 3.0.0? — Aglyph 3.0.0 documentation

# What’s new in release 3.0.0?

- The Python 3.2 lifespan and Python 3.3 lifespan have ended; those versions are no longer actively supported in Aglyph.
- Python 3.6 is now supported. (Cumulatively, Python 2.7, 3.4, 3.5, and 3.6 are currently supported.)
- All deprecated functions, classes, and behaviors have been replaced or removed, most notably:
  - The `aglyph.binder` module has been removed; programmatic configuration is now handled by The Aglyph Context fluent API.
  - The `aglyph.cache` module has been removed (it is an internal implementation detail and should not be part of the public API).
  - The `aglyph.compat` package has become the non-public `aglyph._compat` module (it is an internal implementation detail and should not be part of the public API).
  - The built-in `eval()` function is no longer supported (see Eval really is dangerous) in favor of the safer `ast.literal_eval()`.
- Aglyph is now fully logged and traced via Autologging. Tracing is disabled by default and can enabled by setting the “AGLYPH_TRACED” environment variable.

## Previous releases of Aglyph

- What’s new in release 2.1.1?
- What’s new in release 2.1.0?
- What’s new in release 2.0.0?
- What’s new in release 1.1.1?
- What’s new in release 1.1.0?